package net.sf.corn.gate;

import java.io.Serializable;
import java.util.Set;
import java.util.concurrent.ConcurrentSkipListSet;
/**
 * Represents a meta data that defines a service and optionally its operations as target.
 * Designed to used with filters
 * @author Serhat Dirik
 *
 */
public class ServiceTargetDefinition implements Comparable<Object>, Cloneable,
		Serializable {

	private static final long serialVersionUID = 1929770869037188130L;
	private String serviceNamePattern;
	private Set<String> operationTargets = new ConcurrentSkipListSet<String>();

	public ServiceTargetDefinition(String serviceNamePattern) {
		if (serviceNamePattern == null) {
			throw new IllegalArgumentException("ServiceName Pattern is Null");
		}
		setserviceNamePattern(serviceNamePattern);
	}

	public boolean serviceMatches(String name) {
		if (name == null || name.trim().length() == 0)
			return false;
		return name.matches(serviceNamePattern);
	}
	
	public boolean matches(String serviceName,String operationName){
		return serviceMatches(serviceName) && operationMathes(operationName);
	}
	public String getserviceNamePattern() {
		return serviceNamePattern;
	}

	private void setserviceNamePattern(String serviceNamePattern) {
		if (serviceNamePattern == null
				|| serviceNamePattern.trim().length() == 0) {
			throw new IllegalArgumentException(
					"Null or empty operation name pattern!");
		}
		this.serviceNamePattern = serviceNamePattern;
	}

	public boolean addOperationTarget(String opTarget) {
		if (opTarget == null)
			return true;
		return operationTargets.add(opTarget);
	}

	public boolean removeOperationTarget(String opTarget) {
		if (opTarget == null)
			return true;
		return operationTargets.remove(opTarget);
	}

	public Set<String> getOperationTargets() {
		return operationTargets;
	}

	public boolean operationMathes(String operationName) {
		if (operationTargets == null || operationTargets.size() == 0) {
			return true;
		}
		for (String opTarget : operationTargets) {
			if (operationName.matches(opTarget))
				return true;
		}
		return false;
	}

	@Override
	public int compareTo(Object obj) {
		if (obj == null)
			return 1;
		if (obj instanceof ServiceTargetDefinition)
			return 1;
		ServiceTargetDefinition o = (ServiceTargetDefinition) obj;
		if (serviceNamePattern.compareTo(o.serviceNamePattern) != 0)
			return serviceNamePattern.compareTo(o.serviceNamePattern);
		return 0;
	}

	@Override
	public String toString() {
		return new StringBuilder().append("Target ->").append(serviceNamePattern).append(", ops:").append(operationTargets).toString();
	}

}
