package net.sf.corn.gate;

import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

import net.sf.corn.gate.IDataStage.Scope;


/**
 * Represents a local service call context that used as default for service calls 
 * inside a single JVM
 * @author <b>Serhat Dirik</b>
 *
 */
public class SimpleLocalClientContext implements IClientContext {

	private static final long serialVersionUID = -6535551984169445329L;
	public static final String PROTOCOL_NAME = "local";
	private static IDataStage platformScope = new SimpleConcurrentDataStage(IDataStage.Scope.PLATFORM);
	private static IDataStage applicationScope = new SimpleConcurrentDataStage(IDataStage.Scope.PLATFORM);
	private IDataStage requestScope = new SimpleConcurrentDataStage(IDataStage.Scope.REQUEST);
	private IDataStage sessionScope = new SimpleConcurrentDataStage(IDataStage.Scope.REQUEST);
	private Map<String,Object> responseHeader = new ConcurrentHashMap<String, Object>();
	private Map<String,Object> requestHeader = new ConcurrentHashMap<String, Object>();
	
	public SimpleLocalClientContext() {
	}
	
	public SimpleLocalClientContext(Map<String, Object> requestHeader) {
		if(requestHeader != null){
			this.requestHeader.putAll(requestHeader);
		}
	}
	
	public String getClientUser() {
		return null;
	}

	public boolean isUserInRole(String role) {
		return true;
	}

	public IDataStage getDataStage(Scope type) {
		if(type == null) {
			throw new IllegalArgumentException("Null scope type is requested!");
		}
		if(type.equals(Scope.PLATFORM)){
			return platformScope;
		}	else if(type.equals(Scope.APPLICATION)){
			return applicationScope;
		}else if(type.equals(Scope.REQUEST)){
			return requestScope;
		}else if(type.equals(Scope.SESSION)){
			return sessionScope;
		} 
		return null;
	}


	public String getProtocolName() {
		return PROTOCOL_NAME;
	}


	public String getClientNetworkAddr() {
		return null;
	}


	public int getClientCommunicationPort() {
		return -1;
	}


	public String getClientHostName() {
		return null;
	}


	public boolean isLocal() {
		return true;
	}


	public boolean isProtocolSecure() {
		return true;
	}

	/*public void setSessionScopedDataStage(IDataStage sessionScope) {
		this.sessionScope = sessionScope;
	}
*/

	public String toString() {
		return "SimpleClientContext [getClientUser()=" + getClientUser()
				+ ", getProtocolName()=" + getProtocolName()
				+ ", isLocal()=" + isLocal() 
				+ "]";
	}

	@Override
	public String getServerName() {
		return "localhost";
	}

	@Override
	public int getServerPort() {
		return -1;
	}

	@Override
	public String getServerNetworkAddr() {
		return null;
	}
	@Override
	public Object addToResponseHeader(String key, Object value) {
		return responseHeader.put(key, value);
	}
	@Override
	public Object removeFromResponseHeader(String key) {
		return responseHeader.remove(key);
	}
	@Override
	public Set<String> responseHeaderKeySet() {
		return responseHeader.keySet();
	}
	@Override
	public Object getFromResponseHeader(String key) {
		return responseHeader.get(key);
	}
	@Override
	public boolean containsResponseHeaderKey(String key) {
		return responseHeader.containsKey(key);
	}

	@Override
	public Object getFromRequestHeader(String key) {
		 return requestHeader.get(key);
	}

	@Override
	public Set<String> requestHeaderKeySet() {
	   return requestHeader.keySet();
	}

	@Override
	public Object addToRequestHeader(String key, Object value) {
		return requestHeader.put(key, value);
	}
	
}
